.. _xmldsig:

*************************************
Classes representing xmldsig elements
*************************************

:Author: Roland Hedberg
:Version: |version|

.. module:: XmlDsig
   :synopsis: Classes representing xmldsig elements.

Module
==========

.. automodule:: xmldsig
   :members: 

